==> ebox_0.11.99.orig.tar.gz: ebox-0.11.99/src/EBox/Logs/Composite/ConfigureLog.pm <==
# Copyright (C) 2007 Warp Networks S.L.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License, version 2, as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

# Class: EBox::Test::ConfigureLog


package EBox::Logs::Composite::ConfigureLog;

use base 'EBox::Model::Composite';

use strict;
use warnings;

## eBox uses
use EBox::Gettext;

# Group: Public methods

# Constructor: new
#
#         Constructor for the test Composite
#
# Returns:
#
#       <EBox::Model::Composite> - a test composite
#
sub new
  {

      my ($class) = @_;

      my $self = $class->SUPER::new();

      return $self;

  }

# Group: Protected methods

# Method: _description
#
# Overrides:
#
#     <EBox::Model::Composite::_description>
#
sub _description
  {

      my $description =
        {
         components      => [
			     'ConfigureLogTable',
			     'ForcePurge',
                            ],
         layout          => 'top-bottom',
         name            => 'ConfigureLog',
         compositeDomain => 'Logs',
        };

      return $description;

  }

1;

==> ebox_1.5.orig.tar.gz: ebox-1.5/src/EBox/Logs/Composite/ConfigureLog.pm <==
# Copyright (C) 2007 Warp Networks S.L.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License, version 2, as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

# Class: EBox::Logs::Composite::ConfigureLog

package EBox::Logs::Composite::ConfigureLog;

use base 'EBox::Model::Composite';

use strict;
use warnings;

## eBox uses
use EBox::Gettext;

# Group: Public methods

# Constructor: new
#
#         Constructor for the configure logs composite
#
# Returns:
#
#       <EBox::Logs::Composite::ConfigureLog> - the configure logs composite
#
sub new
  {

      my ($class) = @_;

      my $self = $class->SUPER::new();

      return $self;

  }

# Group: Protected methods

# Method: _description
#
# Overrides:
#
#     <EBox::Model::Composite::_description>
#
sub _description
  {

      my $description =
        {
         components      => [
			     'ConfigureLogTable',
			     'ForcePurge',
                            ],
         layout          => 'top-bottom',
         name            => 'ConfigureLog',
         compositeDomain => 'Logs',
        };

      return $description;

  }

1;
